CanvasRenderer class

Inheritance

Constructors

CanvasRenderer({required Offset origin, required double scale, required List<CartesianItem> items, required List<FreehandItem> freehandItems, required List<Offset>? currentStroke, required bool showGrid, required Color freehandColor, required double freehandWidth, required CartesianCanvasTheme theme, required WorldToScreen worldToScreen, required ScreenToWorld screenToWorld})
const

Properties

currentStroke List<Offset>?
final
freehandColor Color
final
freehandItems List<FreehandItem>
final
freehandWidth double
final
hashCode int
The hash code for this object.
no setterinherited
items List<CartesianItem>
final
origin Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale double
final
screenToWorld ScreenToWorld
final
semanticsBuilder SemanticsBuilderCallback?
Returns a function that builds semantic information for the picture drawn by this painter.
no setterinherited
showGrid bool
final
theme CartesianCanvasTheme
final
worldToScreen ScreenToWorld
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to repaint.
inherited
calculateAdaptiveStep(double currentScaleValue) double
drawAxisLabels(Canvas canvas, Size size) → void
drawGridLines(Canvas canvas, Size size) → void
drawOriginDot(Canvas canvas) → void
formatNumber(double numericValue) String
hitTest(Offset position) bool?
Called whenever a hit test is being performed on an object that is using this custom paint delegate.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to repaint.
inherited
renderTextSpan(Canvas canvas, TextPainter painter, String textualContent, Offset pos, TextStyle style, {bool centerAlignment = false, bool rightAlignment = false}) → void
shouldRebuildSemantics(covariant CustomPainter oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
inherited
shouldRepaint(covariant CanvasRenderer oldDelegate) bool
Called whenever a new instance of the custom painter delegate class is provided to the RenderCustomPaint object, or any time that a new CustomPaint object is created with a new instance of the custom painter delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited