CartesianCanvasState class

Inheritance
Implemented types

Constructors

CartesianCanvasState()

Properties

activeStroke List<Offset>?
getter/setter pair
activeTooltip TooltipData?
getter/setter pair
boundaryRepaintKey GlobalKey<State<StatefulWidget>>
final
context BuildContext
The location in the tree where this widget builds.
no setterinherited
currentOrigin Offset
getter/setter pair
currentScale double
getter/setter pair
drawingMode bool
no setteroverride
gridVisible bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isDrawingModeActive bool
getter/setter pair
isGridVisible bool
getter/setter pair
isInitialized bool
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
previousFocalPoint Offset?
getter/setter pair
previousScaleGesture double?
getter/setter pair
recordedStrokes List<FreehandItem>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget CartesianCanvas
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
applyZoomAtPoint(Offset focalPoint, double zoomFactor) → void
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
captureImage() Future<Image?>
override
clearFreehand() → void
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
detectTooltipIntersection(Offset screenCoordinates) → void
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant CartesianCanvas oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
fitToContent() → void
override
goToPoint(double x, double y) → void
override
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
renderCanvasLayer(Size availableSize) Widget
resetView() → void
override
setDrawingMode(bool isEnabled) → void
override
setGridVisible(bool isVisible) → void
override
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toggleFullScreen() → void
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
transformScreenToWorld(double px, double py) Offset
transformWorldToScreen(double x, double y) Offset
zoomFromCenter(double zoomFactor) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited