FreehandItem class

Inheritance

Constructors

FreehandItem({required List<Offset> worldPoints, Color color = const Color(0xFF1F2937), double strokeWidth = 2.5, StrokeCap cap = StrokeCap.round})
const

Properties

cap StrokeCap
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
final
worldPoints List<Offset>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited