PointItem class

Inheritance

Constructors

PointItem({required double x, required double y, Color color = Colors.blue, double radius = 6.0, String? label, TextStyle? labelStyle, Offset labelOffset = const Offset(10, -18)})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
labelOffset Offset
final
labelStyle TextStyle?
final
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited