SeriesPoint class

Constructors

SeriesPoint({required double x, required double y, String? label, Color? color, double? radius})
const
SeriesPoint.fromMap(Map<String, dynamic> map, {String mapXKey = 'x', String mapYKey = 'y', String? mapLabelKey})
factory

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
radius double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited