fitToContent method
void
fitToContent()
Adjusts the scale and origin to fit all elements currently on the plane.
Implementation
void fitToContent() => canvasDelegate?.fitToContent();
Adjusts the scale and origin to fit all elements currently on the plane.
void fitToContent() => canvasDelegate?.fitToContent();