drawingMode property
bool
get
drawingMode
Returns true if the freehand drawing mode is currently active.
Implementation
bool get drawingMode;
Returns true if the freehand drawing mode is currently active.
bool get drawingMode;