eraserMode property
bool
get
eraserMode
Returns true if the eraser mode is currently active.
Implementation
bool get eraserMode;
Returns true if the eraser mode is currently active.
bool get eraserMode;