gridVisible property
bool
get
gridVisible
Returns true if the background grid is currently visible.
Implementation
bool get gridVisible;
Returns true if the background grid is currently visible.
bool get gridVisible;