CartesianCanvasTheme class

Constructors

CartesianCanvasTheme({Color background = const Color(0xFFF8F9FA), Color axisColor = const Color(0xFF2B2D42), double axisWidth = 1.2, Color gridColor = const Color(0xFFE5E7EB), double gridWidth = 1.0, Color labelColor = const Color(0xFF6B7280), double labelFontSize = 11, Color originDotColor = const Color(0xFF3B82F6), Color tooltipBackground = const Color(0xE61F2937), Color tooltipTextColor = const Color(0xFFF9FAFB)})
const

Properties

axisColor Color
final
axisWidth double
final
background Color
final
gridColor Color
final
gridWidth double
final
hashCode int
The hash code for this object.
no setterinherited
labelColor Color
final
labelFontSize double
final
originDotColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltipBackground Color
final
tooltipTextColor Color
final

Methods

copyWith({Color? background, Color? axisColor, double? axisWidth, Color? gridColor, double? gridWidth, Color? labelColor, double? labelFontSize, Color? originDotColor, Color? tooltipBackground, Color? tooltipTextColor}) CartesianCanvasTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

dark → const CartesianCanvasTheme
light → const CartesianCanvasTheme