CartesianCanvas class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CartesianCanvas
Constructors
-
CartesianCanvas({Key? key, List<
CartesianItem> items = const [], List<WidgetItem> widgetItems = const [], CartesianCanvasTheme theme = CartesianCanvasTheme.light, CartesianCanvasController? controller, bool showControls = true, bool showLegend = true, String? title, double initialScale = 1.0, bool initialShowGrid = true, bool enableFreehandDrawing = false, Color freehandColor = Colors.black, double freehandWidth = 2.0, bool isFullScreen = false, void onFreehandStroke(List<Offset> worldPoints)?, void onTap(double x, double y)?, void onLongPress(double x, double y)?}) -
const
Properties
- controller → CartesianCanvasController?
-
final
- enableFreehandDrawing → bool
-
final
- freehandColor → Color
-
final
- freehandWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialScale → double
-
final
- initialShowGrid → bool
-
final
- isFullScreen → bool
-
final
-
items
→ List<
CartesianItem> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onFreehandStroke
→ void Function(List<
Offset> worldPoints)? -
final
- onLongPress → void Function(double x, double y)?
-
final
- onTap → void Function(double x, double y)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showControls → bool
-
final
- showLegend → bool
-
final
- theme → CartesianCanvasTheme
-
final
- title → String?
-
final
-
widgetItems
→ List<
WidgetItem> -
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CartesianCanvas> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited