cartesian_item library

Classes

CartesianItem
The base class for all drawable items on the Cartesian Plane.
FreehandItem
FunctionItem
ImageItem
PointItem
An item that represents a single point (coordinate) on the Cartesian Plane.
PolygonItem
SegmentItem
SeriesItem
SeriesPoint
TextItem
WidgetItem

Typedefs

ScreenToWorld = Offset Function(double px, double py)
A function signature for converting screen coordinates to world coordinates.
WorldToScreen = Offset Function(double px, double py)
A function signature for converting world coordinates to screen coordinates.