FunctionItem class

Inheritance

Constructors

FunctionItem({required String equation, Color color = Colors.red, double lineWidth = 2.5, String? name})
const

Properties

color Color
final
equation String
final
hashCode int
The hash code for this object.
no setterinherited
lineWidth double
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited