PointItem class

An item that represents a single point (coordinate) on the Cartesian Plane.

Inheritance

Constructors

PointItem({required double x, required double y, Color color = Colors.blue, double radius = 6.0, String? label, TextStyle? labelStyle, Offset labelOffset = const Offset(10, -18)})
const

Properties

color Color
The color of the point dot.
final
hashCode int
The hash code for this object.
no setterinherited
label String?
An optional text label displayed next to the point.
final
labelOffset Offset
The pixel offset applied to the label relative to the center of the point.
final
labelStyle TextStyle?
The style applied to the label text.
final
radius double
The radius of the point dot in screen pixels.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
The X coordinate in the cartesian space.
final
y double
The Y coordinate in the cartesian space.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited