PolygonItem class

Inheritance

Constructors

PolygonItem({required List<(double, double)> vertices, Color? fillColor, Color strokeColor = const Color(0xFF374151), double strokeWidth = 2.0})
const

Properties

fillColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor Color
final
strokeWidth double
final
vertices List<(double, double)>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited