SegmentItem class

Inheritance

Constructors

SegmentItem({required double x1, required double y1, required double x2, required double y2, Color color = const Color(0xFF374151), double strokeWidth = 2.0, bool arrow = false, double arrowSize = 12.0, List<double>? dashPattern})
const

Properties

arrow bool
final
arrowSize double
final
color Color
final
dashPattern List<double>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
final
x1 double
final
x2 double
final
y1 double
final
y2 double
final

Methods

calculateCos(double angleValue) double
calculateSin(double angleValue) double
drawArrowHead(Canvas canvas, Offset point1, Offset point2, Paint linePaint) → void
drawDashedLine(Canvas canvas, Offset point1, Offset point2, Paint linePaint) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited