SeriesItem class

Inheritance

Constructors

SeriesItem({required String name, required List<SeriesPoint> points, required Color color, double pointRadius = 5.0, bool connectPoints = false, double lineWidth = 2.0, bool showPoints = true, StrokeCap lineCap = StrokeCap.round})
const
SeriesItem.fromMaps(List<Map<String, dynamic>> rows, {required String name, required Color color, String mapXKey = 'x', String mapYKey = 'y', String? mapLabelKey, double pointRadius = 5.0, bool connectPoints = false, double lineWidth = 2.0, bool showPoints = true})
factory

Properties

color Color
final
connectPoints bool
final
hashCode int
The hash code for this object.
no setterinherited
lineCap StrokeCap
final
lineWidth double
final
name String
final
pointRadius double
final
points List<SeriesPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPoints bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited