TextItem class

Inheritance

Constructors

TextItem({required double x, required double y, required String text, TextStyle style = const TextStyle(fontSize: 14, color: Color(0xFF1F2937), fontWeight: FontWeight.w500), Offset offset = Offset.zero})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
offset Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TextStyle
final
text String
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void
Called by the canvas to paint this item onto the screen.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited