CartesianCanvasController class
- Inheritance
-
- Object
- ChangeNotifier
- CartesianCanvasController
Constructors
Properties
- canvasDelegate ↔ CartesianCanvasDelegate?
-
getter/setter pair
- drawingMode ↔ bool
-
getter/setter pair
- gridVisible ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
attach(
CartesianCanvasDelegate newDelegate) → void -
captureImage(
) → Future< Image?> -
clearFreehand(
) → void -
detach(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
fitToContent(
) → void -
goToPoint(
double x, double y) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
resetView(
) → void -
setDrawingMode(
bool isEnabled) → void -
setGridVisible(
bool isVisible) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zoomIn(
) → void -
zoomOut(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited