CartesianCanvasDelegate class abstract
- Implementers
Constructors
Properties
- drawingMode → bool
-
no setter
- gridVisible → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureImage(
) → Future< Image?> -
clearFreehand(
) → void -
fitToContent(
) → void -
goToPoint(
double x, double y) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetView(
) → void -
setDrawingMode(
bool val) → void -
setGridVisible(
bool val) → void -
toString(
) → String -
A string representation of this object.
inherited
-
zoomFromCenter(
double factor) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited