CartesianCanvasState class
- Inheritance
-
- Object
- State<
CartesianCanvas> - CartesianCanvasState
- Implemented types
Constructors
Properties
-
activeStroke
↔ List<
Offset> ? -
getter/setter pair
- activeTooltip ↔ TooltipData?
-
getter/setter pair
-
boundaryRepaintKey
→ GlobalKey<
State< StatefulWidget> > -
final
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- currentEraserWidth ↔ double
-
getter/setter pair
- currentOrigin ↔ Offset
-
getter/setter pair
- currentScale ↔ double
-
getter/setter pair
- drawingMode → bool
-
Returns true if the freehand drawing mode is currently active.
no setteroverride
- eraserMode → bool
-
Returns true if the eraser mode is currently active.
no setteroverride
- gridVisible → bool
-
Returns true if the background grid is currently visible.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDrawingModeActive ↔ bool
-
getter/setter pair
- isEraserModeActive ↔ bool
-
getter/setter pair
- isGridVisible ↔ bool
-
getter/setter pair
- isInitialized ↔ bool
-
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
- mousePosition ↔ Offset?
-
getter/setter pair
- previousFocalPoint ↔ Offset?
-
getter/setter pair
- previousScaleGesture ↔ double?
-
getter/setter pair
-
recordedStrokes
→ List<
FreehandItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
undoneStrokes
→ List<
FreehandItem> -
final
- widget → CartesianCanvas
-
The current configuration.
no setterinherited
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
applyZoomAtPoint(
Offset focalPoint, double zoomFactor) → void -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
captureImage(
) → Future< Image?> -
Captures the current visible canvas as an image.
Returns a ui.Image which can be used to save or share the graph.
override
-
clearFreehand(
) → void -
Clears all freehand strokes (including erasures) from the canvas.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
detectTooltipIntersection(
Offset screenCoordinates) → void -
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant CartesianCanvas oldWidget) → void -
Called whenever the widget configuration changes.
override
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
fitToContent(
) → void -
Automatically adjusts the view (scale and origin) to fit all items within the viewport.
override
-
goToPoint(
double x, double y) → void -
Moves the center of the viewport to the specific
xandyworld coordinates.override -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
redoFreehand(
) → void -
Redoes the previously undone freehand stroke or erasure.
override
-
renderCanvasLayer(
Size availableSize) → Widget -
resetView(
) → void -
Resets the canvas view to its initial origin and scale.
override
-
setDrawingMode(
bool isEnabled) → void -
Sets the freehand drawing mode to
val.override -
setEraserMode(
bool isEnabled) → void -
Sets the eraser mode to
val.override -
setGridVisible(
bool isVisible) → void -
Sets the visibility of the background grid to
val.override -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toggleFullScreen(
) → void -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
transformScreenToWorld(
double px, double py) → Offset -
transformWorldToScreen(
double x, double y) → Offset -
undoFreehand(
) → void -
Undoes the last freehand stroke or erasure.
override
-
zoomFromCenter(
double zoomFactor) → void -
Zooms the canvas in or out from the center of the viewport by a given
factor.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited