CartesianItem class abstract
The base class for all drawable items on the Cartesian Plane.
Subclass this to create custom shapes, functions, or annotations that can be rendered onto the CartesianCanvas.
Constructors
- CartesianItem()
-
Default constructor for CartesianItem.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void - Called by the canvas to paint this item onto the screen.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited