paint abstract method
void
paint(
- Canvas canvas,
- Size size,
- WorldToScreen worldToScreen,
- ScreenToWorld screenToWorld,
- double scale,
Called by the canvas to paint this item onto the screen.
The canvas and size are provided by the Flutter framework. Use worldToScreen
to translate mathematical coordinates into on-screen pixels.
Implementation
void paint(
Canvas canvas,
Size size,
WorldToScreen worldToScreen,
ScreenToWorld screenToWorld,
double scale,
);