FreehandItem class
- Inheritance
-
- Object
- CartesianItem
- FreehandItem
Constructors
Properties
- baseScale → double
-
final
- cap → StrokeCap
-
final
- color → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEraser → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
final
-
worldPoints
→ List<
Offset> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void -
Called by the canvas to paint this item onto the screen.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited