FunctionItem class
- Inheritance
-
- Object
- CartesianItem
- FunctionItem
Constructors
- FunctionItem({required String equation, Color color = Colors.red, double lineWidth = 2.5, String? name})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, WorldToScreen worldToScreen, ScreenToWorld screenToWorld, double scale) → void -
Called by the canvas to paint this item onto the screen.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited